@@ -355,7 +355,7 @@ class App:
     # Start server
     # -------------------------------------------------------------------------
 
-    def run_server(self, port=None):
+    def run_server(self, port=None, thread=False):
         # Prevent faulty state synchronization with naive usage
         if self._eager_state_listening:
             self.listen(*list(self.state.keys()))
@@ -365,12 +365,15 @@ class App:
 
         args = self.cli_args
 
-        if port:
+        if port is not None:
             args.port = port
 
         if not args.content:
             args.content = WWW_DIR
 
+        if thread:
+            args.nosignalhandlers = True
+
         if args.launcher:
             CoreServer.start_launcher(args)
             # FIXME we don't support yet self.serve with launcher...
@@ -380,8 +383,20 @@ class App:
             if len(self.serve):
                 endpoints = []
                 for key in self.serve:
-                    endpoints.append(f"{key}={abs_path(self.serve[key], self._root)}")
+                    value = self.serve[key]
+                    if isinstance(value, (list, tuple)):
+                        # tuple are use to describe sync loading (affect client)
+                        endpoints.append(f"{key}={abs_path(value[0], self._root)}")
+                    else:
+                        endpoints.append(f"{key}={abs_path(value, self._root)}")
                 args.fsEndpoints = "|".join(endpoints)
 
             CoreServer.configure(args)
             CoreServer.start_webserver(args)
+
+    def stop_server(self):
+        CoreServer.stop_webserver()
+
+    @property
+    def server_port(self):
+        return CoreServer.port_webserver()
