@@ -95,6 +95,14 @@ class CoreServer(ServerProtocol):
     def start_webserver(args):
         server.start_webserver(options=args, protocol=CoreServer)
 
+    @staticmethod
+    def stop_webserver():
+        server.stop_webserver()
+
+    @staticmethod
+    def port_webserver():
+        return server.get_port()
+
     @staticmethod
     def get_launcher_config(args):
         config = {}
@@ -200,6 +208,7 @@ class CoreServer(ServerProtocol):
 
         self.updateSecret(CoreServer.authentication_token)
 
+    def port_callback(self, port_used):
         if self.app.on_ready:
             try:
                 self.app.on_ready(**self.app.state)
